import * as autoBind from 'auto-bind';
import { BaseResolversVisitor } from 'graphql-codegen-visitor-plugin-common';
import { TypeScriptOperationVariablesToObject } from 'graphql-codegen-typescript';
export class TypeScriptResolversVisitor extends BaseResolversVisitor {
    constructor(pluginConfig, schema) {
        super(pluginConfig, {
            avoidOptionals: pluginConfig.avoidOptionals || false,
            immutableTypes: pluginConfig.immutableTypes || false
        }, schema);
        autoBind(this);
        this.setVariablesTransformer(new TypeScriptOperationVariablesToObject(this.config.scalars, this.convertName, this.config.avoidOptionals, this.config.immutableTypes));
        this._declarationBlockConfig = {
            blockTransformer(block) {
                return `ResolversObject<${block}>`;
            }
        };
    }
    formatRootResolver(schemaTypeName, resolverType) {
        return `${schemaTypeName}?: ${resolverType},`;
    }
    clearOptional(str) {
        if (str.startsWith('Maybe')) {
            return str.replace(/Maybe<(.*?)>$/, '$1');
        }
        return str;
    }
    ListType(node) {
        return `Maybe<${super.ListType(node)}>`;
    }
    wrapWithListType(str) {
        return `${this.config.immutableTypes ? 'ReadonlyArray' : 'Array'}<${str}>`;
    }
    NamedType(node) {
        return `Maybe<${super.NamedType(node)}>`;
    }
    NonNullType(node) {
        const baseValue = super.NonNullType(node);
        return this.clearOptional(baseValue);
    }
}
//# sourceMappingURL=visitor.js.map